trait ContextRule<'a>: FontRead<'a> {
// Required methods
fn parse(&self) -> ParsedRule<'a>;
fn first_input(&self) -> Option<u16>;
}Required Methods
Sourcefn parse(&self) -> ParsedRule<'a>
fn parse(&self) -> ParsedRule<'a>
Parse all of the rule’s fields in one pass.
Sourcefn first_input(&self) -> Option<u16>
fn first_input(&self) -> Option<u16>
The first glyph/class of the input sequence, or None if the input
sequence is empty.
Much cheaper than a full parse; used by the skip-ahead loops, which discard most of the rules they visit.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.